@@ -76,7 +76,7 @@ main (int argc, char *argv[])
   locale_init();
 
   /* Init threads */
-  if (g_thread_supported()) {
+  if (!g_thread_supported()) {
 	  g_thread_init(NULL);
   }
   gdk_threads_init();
